=begin
Copyright (c) TIG 2011
Permission to use, copy, modify, and distribute this software for 
any purpose and without fee is hereby granted, provided that the above
copyright notice appear in all copies.
This software is provided "as is" and without any express or
implied warranties, including, without limitation, the implied
warranties of merchantability and fitness for a particular purpose.
Name:
 ExportBatchOBJ.rb
Usage:
Sketchup Menu > File > Export Batch OBJ...
Answer the options dialog, then OK.
[Note that a 'usual' set of 'options' shown - adjust as desired]
Select one SKP from a folder of SKPs to be exported, then OK.
All SKPs in that folder are opened, exported as OBJ [using the given 
settings] and then closed.  You might be prompted to save a SKP - answer 
'No'.  If the original SKP was unsaved the last exported SKP remains 
open, otherwise the original SKP's window is restored.
All exported OBJ files are found in a [new] subfolder in the selected 
folder called 'OBJs' - there might also be subfolders made to contain 
associated texture files, each named after its OBJ.
Any preexisting OBJ files will be overwritten without a warning.
=end
#-----------------------------------------------------------------------------
require 'sketchup.rb'
#-----------------------------------------------------------------------------
module TIG
###
def self.exportBatchOBJ()
  ###
  model=Sketchup.active_model
  opts= {:selectionset_only    => false,### always
         :triangulated_faces   => true,
         :doublesided_faces    => true,
         :edges                => false,
         :texture_maps         => true,
         :swap_xy              => true,
         :units                => "Meters",
         :double_precision     => true, ### always
         :vertex_normals       => true  ### always
        }
  ### get user settings
  refs= [:selectionset_only,
         :triangulated_faces,
         :doublesided_faces,
         :edges,
         :texture_maps,
         :swap_xy,
         :units
        ]
  prms= ["Selection Only: ",
         "Triangulate All Faces: ",
         "Export two-sided faces: ",
         "Export edges: ",
         "Texture Maps: ",
         "Swap YZ coord: ",
         "Units: "
        ]
  vals= ["False",
         "True",
         "True",
         "False",
         "True",
         "True",
         "Meters"
        ]
  pops= ["True|False",
         "True|False",
         "True|False",
         "True|False",
         "True|False",
         "True|False",
         "Model Units|Inches|Feet|Yards|Miles|Millimeters|Centimeters|Meters|Kilometers"
        ]
  titl= "Export Batch OBJ Options"
  results=UI.inputbox(prms,vals,pops,titl)
  return nil if not results
  results.each_with_index{|r,i|
    if r=="True"
      opts[refs[i]]=true
    else
      opts[refs[i]]=false
    end
  }
  ###
  opath=model.path
  if not opath or opath==''
    pwd=Dir.getwd()
  else
    pwd=File.dirname(opath)
  end
  pwd.tr!("\\","/")
  ffolder=UI.openpanel "Export Batch OBJ: Pick Any SKP File + OK...", pwd , "*.SKP"
  return nil if not ffolder
  folder=File.dirname(ffolder)
  return nil if not folder or not File.exist?(folder)
  skps=[]
  Dir.entries(folder).each{|f|skps << File.join(folder,f) if File.extname(f).downcase=='.skp'}
  objs=File.join(folder,'OBJs')
  Dir.mkdir(objs) if not File.exist?(objs)
  skps.each{|skp|
    Sketchup.open_file(skp)
    name=File.basename(skp, '.*')
    path=File.join(objs, name+'.obj')
    model.export(path, opts)
  }
  if not opath or opath==''
    Sketchup.send_action('terminate:')
  else
    Sketchup.open_file(opath)
  end
  ###
end
###
if not file_loaded?(File.basename(__FILE__))
  UI.menu("File").add_item("Export Batch OBJ..."){TIG.exportBatchOBJ()}
end
file_loaded(File.basename(__FILE__))
###
end#module
#